pub struct Ether<T> {
data: SyncUnsafeCell<T>,
}Expand description
A unprotectected global object on a “I know what I’m doing basis”. every reference to such object must be marked unsafe.
Fields
data: SyncUnsafeCell<T>pub struct Ether<T> {
data: SyncUnsafeCell<T>,
}A unprotectected global object on a “I know what I’m doing basis”. every reference to such object must be marked unsafe.
data: SyncUnsafeCell<T>